@@ -1,5 +1,5 @@
-use sqlx::{MySqlPool, mysql::MySqlRow};
 use sea_query::{MysqlQueryBuilder, SelectStatement};
+use sqlx::{mysql::MySqlRow, MySqlPool};
 
 sea_query::sea_query_driver_mysql!();
 use sea_query_driver_mysql::bind_query;
@@ -16,9 +16,7 @@ pub trait IntoExecutor {
 
 impl IntoExecutor for MySqlPool {
     fn into_executor(self) -> Executor {
-        Executor {
-            pool: self
-        }
+        Executor { pool: self }
     }
 }
 
@@ -29,6 +27,9 @@ impl Executor {
         debug_print!();
 
         let query = bind_query(sqlx::query(&sql), &values);
-        query.fetch_all(&mut self.pool.acquire().await.unwrap()).await.unwrap()
+        query
+            .fetch_all(&mut self.pool.acquire().await.unwrap())
+            .await
+            .unwrap()
     }
 }
