@@ -8,5 +8,7 @@ macro_rules! debug_print {
 // Non-debug version
 #[cfg(not(feature = "debug-print"))]
 macro_rules! debug_print {
-    ($( $args:expr ),*) => {}
-}
\ No newline at end of file
+    ($( $args:expr ),*) => {
+        true;
+    };
+}
